#include <stdio.h>
#include <assert.h>

#define MAXN 1000000

int N;
int C[MAXN];        // capacity
int level[MAXN+1];  // filled level
int next[MAXN+1];   // next flooding barrel

void put(int k, int u) {
    // process barrels in order (just in case of overflow)
    for(int i = u; i < N; i = next[i]) {
        if(level[i] + k <= C[i]) {  // no overflow; last barrel to process
            level[i] += k;
            for(int j = u, tmp; j < i; j = tmp) { tmp = next[j]; next[j] = i; }     // speed up the next calls
            return;
        }
        else {  // fill in the current barrel
            k -= C[i] - level[i];
            level[i] = C[i];
        }
    }
}

int measure(int q) {
	return level[q];
}

int main() {
	FILE *fr, *fw;
	int T, i, k, u, q;
	char cmd;

	fr = stdin;//fopen("input.txt", "r");
	fw = stdout;//fopen("output.txt", "w");
	assert(2 == fscanf(fr, "%d %d", &N, &T));
	for(i=0; i<N; i++) {
		assert(1 == fscanf(fr, "%d", &C[i]));
		level[i] = 0;
		next[i] = i+1;
	}
	for(i=0; i<T; i++) {
		assert(1 == fscanf(fr, " %c", &cmd));
		if (cmd == 'P') {
			assert(2 == fscanf(fr, "%d %d", &k, &u));
			put(k, u);
		} else {
			assert(1 == fscanf(fr, "%d", &q));
			fprintf(fw, "%d\n", measure(q));
		}
	}

	fclose(fr);
	fclose(fw);
	return 0;
}
